<template lang="pug">
div
    div(v-if="currentRoute.signed_status").col-md-10.col-xl-7.h-100.d-flex.align-items-center.flex-column.justify-content-center.mx-auto.text-center.mt-4.mb-4.mt-lg-0
        .mt-4.mt-lg-0.mb-5(ref="success-icon" style="width: 100px;")
        h4.font-weight-600.mb-3 Success! Your Special Order is Confirmed
        p.mb-4 
        | You've successfully signed the Special Order Terms and Conditions. 
        | We appreciate your trust in us and look forward to fulfilling your unique requirements.
    .app-special-orders__container.px-3
        h2.text-center.font-weight-600.mb-4 Special Order Terms and Conditions
        div(v-if="currentRoute.invoice_detail.length > 0").card.p-3.mb-4
            .d-flex.align-items-center.justify-content-between.cursor-pointer(
                @click.prevent="onShowProductsInfo"
            )
                h5.mb-0.font-weight-600 Product(s)
                i.fas.fa-sm(
                    :class='collapse ? "fa-chevron-up" : "fa-chevron-down"')
            b-collapse(v-model="collapse",role="tabpanel",accordion="my-accordion")
                div.mt-3
                    div(v-for="(product, index) in currentRoute.invoice_detail", :key="index", :class="index > 0 ? 'border-top' : ''").d-flex.pt-3.mt-2
                        img.object-contain.object-top.product-img(
                            :src="product.image" 
                            width="80" 
                            height="80" 
                            loading="lazy" 
                            @error="onErrorImg($event,product.brand_image)"
                        )
                        .ml-3.flex-grow-1
                            p.mb-1 {{product.name}}
                            p.mb-1.text-gray Model: {{product.model}} • {{ product.condition_name }}
                            p.mb-1.font-weight-600 ${{ product.price }}
                            p.mb-1.text-gray QTY: {{ product.quantity }}
        div(v-if="currentRoute.terms_document.length > 0").card.p-3.mb-4 
            h5.mb-0.font-weight-600 Special Terms
            div(v-for="file in currentRoute.terms_document").border.border-sm.rounded.mt-2.p-2.d-flex.justify-content-between
                .d-flex.align-items-center
                    img(src="/img/icon/pdf-icon.svg" alt="pdf icon").mx-2
                    span.text-wrap {{ file.name }}
                .d-flex.align-items-center
                    a.text-blue.border-right.pr-2.mr-2(:href="file.path_url", target="_blank")
                        i.fas.fa-sm.fa-eye.mr-1
                        | view
                    a(@click="downloadFile(file.path_url,file.name)").cursor-pointer.text-blue
                        i.fas.fa-sm.fa-download.mr-1
                        | download
        div(v-if="currentRoute.terms_condition").card.p-3.mb-4
            h5.mb-0.font-weight-600 {{ currentRoute.terms_condition.type }} Terms and Conditions 
            div.mt-2(v-html="currentRoute.terms_condition.terms_condition")
        div(v-if="!currentRoute.signed_status").card.p-3.mb-4
            app-alert.mb-3.d-flex.align-items-center(variant="primary") 
                span.material-icons.icon-lg.mr-2 info
                | Please read the full Special Order Terms and Conditions before entering your name and signature.
            b-form.mt-3.row
                b-form-group(
                    label="First Name"
                    :class="{'is-invalid' : validate.firstname}" 
                    ).col-md.font-weight-600
                    app-input(
                        v-model="form.firstname"
                        :isInvalid="validate.firstname"
                        :disabled="currentRoute.signed_status"
                        @input="onInput"
                    )
                    span(v-show="validate.firstname").text-danger.font-weight-400
                        The first name field is required
                b-form-group(label="Last Name").col-md.font-weight-600
                    app-input(
                        v-model="form.lastname"
                        :is-invalid="validate.lastname"
                        :disabled="currentRoute.signed_status"
                    )
                    span(v-show="validate.lastname").text-danger.font-weight-400
                        The last name field is required
            template(v-if="currentRoute.collect_signature_status")
                div.d-flex.justify-content-between.align-items-center.mx-1
                    div
                        label.m-0.font-weight-600 Signature
                        p.text-gray Draw your signature below
                    a.text-blue.cursor-pointer(
                        v-if="confirm" 
                        @click.prevent="onEditSignature")
                        i.fas.fa-sm.fa-pen.mr-2
                        span Edit
                div.border.border-sm.rounded.p-2
                    template(v-if="!currentRoute.signed_status")
                        vue-signature-pad(
                            id="signature",
                            width="100%",
                            height="170px",
                            ref="signaturePad",
                            :options="options")
                        div(v-if="!confirm")
                            hr.mt-0.p-0
                            .d-flex.justify-content-between
                                app-button(
                                    variant="outline-primary",
                                    @click="onClearSignature") Clear 
                                app-button(@click="onConfirm") Confirm
                    img(v-else, :src="form.fileSignature", height="170px")
            client-only
                app-button(:disabled="disabledButton",:loading="loading" @click="onSubmit").mt-3.w-100 Agree and Condition
        app-sales-person(:data="currentRoute.sales_person").mb-4
</template>
    
<script>
import AppAlert from '@/components/atoms/AppAlert'
import AppInput from '@/components/atoms/AppInput'
import AppButton from '@/components/atoms/AppButton'
import AppSalesPerson from '@/components/template/AppSalesPerson'
import SuccessIcon from '@/assets/animation/SuccessIcon.json'
import { mapGetters, mapActions } from 'vuex'

export default {
    name : 'special-order-terms',
    scrollToTop: false,
    components : {
        AppSalesPerson,
        AppAlert,
        AppInput,
        AppButton
    },
    computed: {
        ...mapGetters({
            currentRoute: 'currentRoute'
        }),
        disabledButton(){
            return (!this.confirm || this.currentRoute.signed_status)
        },
    },
    created(){
        this.$nextTick(() => {
            this.loadSuccessIcon()
        })
        this.fillForm()
    },
    data: () => ({
        collapse: true,
        confirm: false,
        options: {
            penColor: "#000"
        },
        validate: {
            firstname : false,
            lastname : false,
        },
        loading: false,
        form : {
            firstname : "",
            lastname : "",
            fileSignature : null
        }
    }),
    watch : {
        'form.firstname' : function (value){
            if(value){
                this.validate.firstname = false
            }else{
                this.validate.firstname = true
            }
        },
        'form.lastname' : function (value){
            if(value){
                this.validate.lastname = false
            }else{
                this.validate.lastname = true
            }
        }
    },
    methods:{
        ...mapActions({
            postSignSpecialOrder: 'postSignSpecialOrder',
            getSpecialOrder : 'getSpecialOrder'
        }),
        onShowProductsInfo(){
            this.collapse = !this.collapse
        },
        onClearSignature(){
            this.$refs.signaturePad.clearSignature()
        },
        onConfirm(){
            const { isEmpty, data } = this.$refs.signaturePad.saveSignature();
            if(isEmpty) return this.confirm = false

            this.$refs.signaturePad.lockSignaturePad()
            const byteCharacters = atob(data.split(',')[1]);
            const byteNumbers = new Array(byteCharacters.length);
            for (let i = 0; i < byteCharacters.length; i++) {
                byteNumbers[i] = byteCharacters.charCodeAt(i);
            }
            const byteArray = new Uint8Array(byteNumbers);
            const blob = new Blob([byteArray], { type: 'image/png' });
           
            this.fileSignature = blob
            this.confirm = true
        },
        onErrorImg(event, brand_image) {
            if (brand_image) {
                event.target.src = brand_image
            } else {
                event.target.src = '/image-error.webp'
            }
        },
        async onSubmit(){
            if(this.form.firstname == '' || this.form.lastname == ''){
                this.validate.firstname = this.form.firstname == '' ? true : false
                this.validate.lastname = this.form.lastname == '' ? true : false
                return 
            }
            const formData = new FormData()
            formData.append('link',this.$route.query.track)
            formData.append('first_name',this.form.firstname)
            formData.append('last_name',this.form.lastname)
            if(this.fileSignature)
                formData.append('signature_file', this.fileSignature, 'signature.png');  

            this.loading = true
            try {
                await this.postSignSpecialOrder(formData)
                await this.getSpecialOrder()
            } finally {
                this.fillForm()
                this.loading = false
                this.confirm = false
                
                this.$nextTick(() => {
                    window.scrollTo({
                        top: 0,
                        behavior: 'smooth',
                    })
                    this.loadSuccessIcon()
                })
            }
        },
        onEditSignature(){
            this.$refs.signaturePad.openSignaturePad()
            this.confirm = false
        },
        loadSuccessIcon() {
            this.$lottie.loadAnimation({
                container: this.$refs['success-icon'],
                renderer: 'svg',
                loop: true,
                autoplay: true,
                animationData: SuccessIcon,
            })
        },
        fillForm(){
            if(this.currentRoute.signed_details){
                this.form.firstname = this.currentRoute.signed_details.first_name
                this.form.lastname = this.currentRoute.signed_details.last_name
                this.form.fileSignature = this.currentRoute.signed_details.signature_url
            }
        },
        downloadFile(url,filename){
            this.$axios.get(url,{
                responseType: 'blob',
            })
            .then((response) => {
                const fileURL = window.URL.createObjectURL(new Blob([response.data]));
                var fileLink = document.createElement('a');
                fileLink.href = fileURL;
                fileLink.setAttribute('download', filename);
                document.body.appendChild(fileLink);
                fileLink.click();
            })
        }
    }
}

</script>

<style lang="scss" scoped src="./index.scss"></style>
